#include <QtCore/QCoreApplication>
#include <QTextStream>
#include <QStringList>
#include <QFile>
#include <QDateTime>
#include "../qjhhash.h"

int main(int argc, char *argv[])
{
  QCoreApplication a(argc, argv);
  QTextStream out(stdout);
  if (a.arguments().size() == 2) // one command line argument -> hash that
  {
    out << "jh-256 of '" << a.arguments().at(1).toAscii() << "':" << endl;
    out << QJHHash(a.arguments().at(1)).toHexString() << endl;
  }
  
  else if (a.arguments().size() == 3) // two command line arguments -> first must be "-file" and second the path to the file to hash
  {
    if (a.arguments().at(1) != "-file")
    {
      out << "For file hashing, first command line argument must be '-file' and second the path to the file" << endl;
      return -1;
    }
    // get file size for speed calculation:
    QFile file(a.arguments().at(2));
    if (!file.open(QFile::ReadOnly))
    {
      out << "Couldn't open file!" << endl;
      return -1;
    }
    qint64 fileSize = file.size();
    file.close();
    out << "Calculating hash (" << fileSize/(1024.0*1024.0) << " MiB)..." << flush;
    qint64 startTime = QDateTime::currentMSecsSinceEpoch();
    QJHHash hash;
    hash.file(a.arguments().at(2));
    qint64 duration = QDateTime::currentMSecsSinceEpoch()-startTime;
    if (duration > 0)
      out << "done (" << duration << " ms, " << fileSize/(duration/1000.0*1024.0*1024.0) << " MiB/s)" << endl;
    else
      out << "done (< 1 ms)" << endl;
    out << "jh-256 of file " << a.arguments().at(2) << ":" << endl;
    out << hash.toHexString() << endl;
  }
  
  else
  {
    out << "Please provide one or two command line arguments. Use quotes when they contain spaces." << endl;
    return -1;
  }
  
  return 0;
}
